@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Warp Networks S.L.
+# Copyright (C) 2008-2010 eBox Technologies S.L.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2, as
@@ -71,6 +71,7 @@ sub new
 #
 #   (NAMED)
 #   domain_name - String domain's name
+#   ipaddr      - String domain's IP address *(Optional)* Default value: undef
 #   hostnames  - array ref containing the following hash ref in each value:
 #
 #                name        - host's name
@@ -99,22 +100,29 @@ sub addDomain
         throw EBox::Exceptions::MissingArgument('name');
     }
 
-   my $id = $self->addRow('domain' => $name);
+    my $id;
+    my $address = delete $params->{'ipaddr'};
 
-   unless (defined($id)) {
-       throw EBox::Exceptions::Internal("Couldn't add domain's name: $name");
-   }
+    if (defined($address)) {
+        $id = $self->addRow('domain' => $name, 'ipaddr' => $address);
+    } else {
+        $id = $self->addRow('domain' => $name);
+    }
 
-   my $hostnames = delete $params->{'hostnames'};
-   return unless (defined($hostnames) and @{$hostnames} > 0);
+    unless (defined($id)) {
+        throw EBox::Exceptions::Internal("Couldn't add domain's name: $name");
+    }
 
-   my $hostnameModel =
+    my $hostnames = delete $params->{'hostnames'};
+    return unless (defined($hostnames) and @{$hostnames} > 0);
+
+    my $hostnameModel =
    		EBox::Model::ModelManager::instance()->model('HostnameTable');
 
-   $hostnameModel->setDirectory($self->{'directory'} . "/$id/hostnames");
-   foreach my $hostname (@{$hostnames}) {
-       $hostnameModel->addHostname(%{$hostname});
-   }
+    $hostnameModel->setDirectory($self->{'directory'} . "/$id/hostnames");
+    foreach my $hostname (@{$hostnames}) {
+        $hostnameModel->addHostname(%{$hostname});
+    }
 }
 
 # Method: addedRowNotify
